%% set_rotfuncs - Fill in funcs structure for use with DDE-Biftool, rotational symmetric case
%%
function funcs=set_rotfuncs(varargin)
%% Named arguments
%
% * |'sys_rhs'| (mandatory), 
% * |'rotation'| (mandatory),
% * |'exp_rotation'| (mandatory),
% * |'sys_ntau'|, 
% * |'sys_cond'|,
% * |'sys_deri'| (unused),
% * |'sys_dtau'| (unused).
%
% See rotsym_demo for example usage
% uses defaults df_deriv for partial derivatives
%
% (c) DDE-BIFTOOL v. 3.2a(319), 31/01/2019
%

%% Process options
defaults={'rotation',[],'exp_rotation',[],'rot_tol',1e-8,'hjac',1e-6};
[options,pass_on]=dde_set_options(defaults,varargin,'pass_on');
rot_tol=options.rot_tol;
funcs=set_funcs(pass_on{:});
funcs.p_vectorized=false;
%% check rotation matrices
if isempty(options.rotation)
    error('rotation matrix must be given as argument ''rotation''');
else
    funcs.rotation=options.rotation;
end
if isempty(options.exp_rotation)
    funcs.exp_rotation=@(phi)expm(funcs.rotation*phi);
else
    funcs.exp_rotation=options.exp_rotation;
end
% test comaptibility
phi=linspace(0,2*pi,10);
for i=1:length(phi)
    err=expm(funcs.rotation*phi(i))-funcs.exp_rotation(phi(i));
    if max(abs(err))>rot_tol
        error('exp(rot*phi)~=exp_rotation(phi) for phi=%g',phi(i));
    end
end
err=funcs.exp_rotation(2*pi)-eye(size(funcs.rotation));
if max(abs(err))>rot_tol
    error('exp(rot*2*pi)~=Id');
end
err=funcs.rotation+funcs.rotation.';
if max(abs(err))>rot_tol
    error('rot~=-rot^T');
end

%% modify sys_rhs to include shift to rotating coordinates
funcs.orig_rhs=funcs.sys_rhs;
rot_sys_rhs=@(xx,p)rot_rhs(xx,p,funcs.rotation,funcs.exp_rotation,...
    funcs.orig_rhs,funcs.sys_tau,funcs.x_vectorized);
funcs.sys_rhs=@(x,p)dde_wrap_rhs(x,p,rot_sys_rhs,funcs.x_vectorized,funcs.p_vectorized);
%% set derivatives to defaults if not given by user
if funcs.sys_deri_provided || funcs.sys_dirderi_provided
    funcs.sys_dirderi_provided=false;
    funcs.sys_deri_provided=false;
    warning('set_rotfuncs:sys_deri',...
        'set_rotfuncs: No support yet for passing on user-defined derivatives.');
end
funcs.add_deriv=@add_deriv;
funcs=add_deriv(funcs);
%% modify sys_cond to include fixing of rotational phase
funcs.orig_cond=funcs.sys_cond;
funcs.sys_cond=@(p)rot_cond(p,funcs.rotation,funcs.orig_cond);
%% state-dependent delays currently not supported
if funcs.tp_del
    error('State-dependent delays are not supported.')
end
if isempty(funcs.sys_dtau) % unused
    funcs.sys_dtau=@(x,p,nx,np,v)df_derit(funcs,x,p,nx,np,v);
end
end
%%
function funcs=add_deriv(funcs)
derivbase=@(xx,p,dxx,dp)funcs.sys_rhs(xx,p);
for order=1:2
    funcs.sys_dirderi{order}=@(x,p,dx,dp)dde_dirderiv(derivbase,...
        x,p,dx,dp,order,'nf',size(x,1),'hjac',funcs.hjac(order));
end
funcs.sys_deri=...
    @(x,p,nx,np,v)dde_gen_deriv(funcs.sys_dirderi,x,p,nx,np,v,1);
end